/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.ri.client;

import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

class DefaultModelBundle
{

  /** Singleton instance. */
  private static final DefaultModelBundle instance =
    new DefaultModelBundle();

  /** Creates a new {@code DefaultModelBundle} instance. */
  DefaultModelBundle()
  {
    this.getMessage ( "invalidMultiplicity", Locale.getDefault() );
    this.getMessage ( "noValidationWarning", Locale.getDefault() );
    this.getMessage ( "missingImplementation", Locale.getDefault() );
    this.getMessage ( "unresolvedImplementation", Locale.getDefault() );
    this.getMessage ( "missingClassloaderError", Locale.getDefault() );
  }

  /**
   * Gets the {@code DefaultModelBundle} singleton.
   *
   * @return the {@code DefaultModelBundle} singleton.
   */
  static DefaultModelBundle getInstance()
  {
    return instance;
  }

  String getInvalidMultiplicityText ( final Locale locale )
  {
    return this.getMessage ( "invalidMultiplicity", locale );
  }

  MessageFormat getInvalidMultiplicityMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "invalidMultiplicity", locale ), locale );
  }
  String getNoValidationWarningText ( final Locale locale )
  {
    return this.getMessage ( "noValidationWarning", locale );
  }

  MessageFormat getNoValidationWarningMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "noValidationWarning", locale ), locale );
  }
  String getMissingImplementationText ( final Locale locale )
  {
    return this.getMessage ( "missingImplementation", locale );
  }

  MessageFormat getMissingImplementationMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "missingImplementation", locale ), locale );
  }
  String getUnresolvedImplementationText ( final Locale locale )
  {
    return this.getMessage ( "unresolvedImplementation", locale );
  }

  MessageFormat getUnresolvedImplementationMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "unresolvedImplementation", locale ), locale );
  }
  String getMissingClassloaderErrorText ( final Locale locale )
  {
    return this.getMessage ( "missingClassloaderError", locale );
  }

  MessageFormat getMissingClassloaderErrorMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "missingClassloaderError", locale ), locale );
  }

  /**
   * Gets a message for a given key and locale.
   *
   * @param key the key of the message to return.
   * @param locale the locale of the message.
   *
   * @return message for {@code key} using {@code locale}.
   */
  private String getMessage( final String key, Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return ResourceBundle.getBundle( "org/jdtaus/core/container/ri/client/DefaultModel",
                                     locale ).getString( key );

  }
}
